@@ -430,12 +430,12 @@ def apply_patches():
             raise NoIntegrationDefined()
         return resource_method["methodIntegration"]
 
-    if not hasattr(apigateway_models.APIGatewayBackend, "put_rest_api"):
-        apigateway_response_restapis_individual_orig = APIGatewayResponse.restapis_individual
-        APIGatewayResponse.restapis_individual = apigateway_response_restapis_individual
-        apigateway_response_resource_individual_orig = APIGatewayResponse.resource_individual
-        APIGatewayResponse.resource_individual = apigateway_response_resource_individual
-        apigateway_models.APIGatewayBackend.put_rest_api = apigateway_models_backend_put_rest_api
+    # TODO: put_rest_api now available upstream - see if we can leverage some synergies
+    apigateway_response_restapis_individual_orig = APIGatewayResponse.restapis_individual
+    APIGatewayResponse.restapis_individual = apigateway_response_restapis_individual
+    apigateway_response_resource_individual_orig = APIGatewayResponse.resource_individual
+    APIGatewayResponse.resource_individual = apigateway_response_resource_individual
+    apigateway_models.APIGatewayBackend.put_rest_api = apigateway_models_backend_put_rest_api
 
     if not hasattr(apigateway_models.APIGatewayBackend, "update_deployment"):
         apigateway_models.APIGatewayBackend.update_deployment = backend_update_deployment
